## aios

asynchronous state, transition and abstraction manager for Python 3.5+

```bash
pip install aios
```

[Docs are available](http://aios.readthedocs.org) - but are a work in progress.

### Features

* State machine
* Class hierarchy management

#### Todo

* Timed & repeated actions
* Cron/scheduled actions

### Demo

* add demo code *

